:github_url: https://github.com/j-bac/elpigraph-python/tree/master/elpigraph-python/elpigraph/_topologies.py#L255-L497



elpigraph.computeElasticPrincipalTree
=====================================

.. currentmodule:: elpigraph

.. autofunction:: computeElasticPrincipalTree